@@ -14,6 +14,8 @@ class SourceTypes(str, Enum):
     mobileapp_in_progress = 'mobileapp_in_progress'
     mobileapp_ready = 'mobileapp_ready'
     mobileapp_submit_facebook = 'mobileapp_submit_facebook'
+    report_thread = 'report_thread'
+    report_comment = 'report_comment'
 
 
 @dataclass
