@@ -1,7 +1,7 @@
 import json
 from typing import Any
 
-from utils.abstract_encoder import AbstractEncoder
+from notification_server_connector.utils.abstract_encoder import AbstractEncoder
 
 
 class JsonEncoder(AbstractEncoder):
